@@ -14,6 +14,10 @@ LDAPObject_bind(LDAPObject *self, PyObject *args)
 	char *who;
 	char *password;
 	struct berval passwd = {0, NULL};
+	PyObject *controls = NULL;
+	LDAPObjectControl *ldapoc = NULL;
+	LDAPControl **sctrls = NULL;
+	LDAPControl **cctrls = NULL;
 	int rc;
 	int msgid;
 
@@ -22,16 +26,20 @@ LDAPObject_bind(LDAPObject *self, PyObject *args)
 		return NULL;
 	}
 
-	if (!PyArg_ParseTuple(args, "ss", &who, &password))
+	if (!PyArg_ParseTuple(args, "ss|O!", &who, &password, &LDAPObjectControlType, &controls))
 		return NULL;
 
-	// ldap_set_option
-	// ldap_start_tls_s
 	passwd.bv_val = password;
 	passwd.bv_len = strlen(passwd.bv_val);
 
+	if (controls) {
+		ldapoc = (LDAPObjectControl *)controls;
+		sctrls = ldapoc->sctrls;
+		cctrls = ldapoc->cctrls;
+	}
+
 	LDAP_BEGIN_ALLOW_THREADS
-	rc = ldap_sasl_bind(self->ldap, who, LDAP_SASL_SIMPLE, &passwd, NULL, NULL, &msgid); // CONTROL
+	rc = ldap_sasl_bind(self->ldap, who, LDAP_SASL_SIMPLE, &passwd, sctrls, cctrls, &msgid);
 	LDAP_END_ALLOW_THREADS
 	if (msgid == -1) {
 		PyErr_SetString(LDAPError, ldap_err2string(rc));
